diff --git a/core/lib/Drupal/Core/Updater/Theme.php b/core/lib/Drupal/Core/Updater/Theme.php
index 7ac70f0..115844f 100644
--- a/core/lib/Drupal/Core/Updater/Theme.php
+++ b/core/lib/Drupal/Core/Updater/Theme.php
@@ -101,7 +101,7 @@ public function postInstallTasks() {
     return [
       $default_options + [
         '#url' => Url::fromRoute('system.themes_page'),
-        '#title' => t('Install newly added themes'),
+        '#title' => t('Enable newly added themes'),
       ],
       $default_options + [
         '#url' => Url::fromRoute('system.admin'),
diff --git a/core/modules/system/src/Controller/SystemController.php b/core/modules/system/src/Controller/SystemController.php
index 4af1dcb..0971238 100644
--- a/core/modules/system/src/Controller/SystemController.php
+++ b/core/modules/system/src/Controller/SystemController.php
@@ -258,10 +258,10 @@ public function themesPage() {
             }
             if ($theme_uninstallable) {
               $theme->operations[] = [
-                'title' => $this->t('Uninstall'),
+                'title' => $this->t('Disable'),
                 'url' => Url::fromRoute('system.theme_uninstall'),
                 'query' => $query,
-                'attributes' => ['title' => $this->t('Uninstall @theme theme', ['@theme' => $theme->info['name']])],
+                'attributes' => ['title' => $this->t('Disable @theme theme', ['@theme' => $theme->info['name']])],
               ];
             }
             $theme->operations[] = [
@@ -275,16 +275,16 @@ public function themesPage() {
         }
         else {
           $theme->operations[] = [
-            'title' => $this->t('Install'),
+            'title' => $this->t('Enable'),
             'url' => Url::fromRoute('system.theme_install'),
             'query' => $query,
-            'attributes' => ['title' => $this->t('Install @theme theme', ['@theme' => $theme->info['name']])],
+            'attributes' => ['title' => $this->t('Enable @theme theme', ['@theme' => $theme->info['name']])],
           ];
           $theme->operations[] = [
-            'title' => $this->t('Install and set as default'),
+            'title' => $this->t('Enable and set as default'),
             'url' => Url::fromRoute('system.theme_set_default'),
             'query' => $query,
-            'attributes' => ['title' => $this->t('Install @theme as default theme', ['@theme' => $theme->info['name']])],
+            'attributes' => ['title' => $this->t('Enable @theme as default theme', ['@theme' => $theme->info['name']])],
           ];
         }
       }
diff --git a/core/modules/system/src/Tests/System/ThemeTest.php b/core/modules/system/src/Tests/System/ThemeTest.php
index 29d88a3..d0e372e 100644
--- a/core/modules/system/src/Tests/System/ThemeTest.php
+++ b/core/modules/system/src/Tests/System/ThemeTest.php
@@ -410,9 +410,9 @@ public function testUninstallingThemes() {
    */
   public function testInstallAndSetAsDefault() {
     $this->drupalGet('admin/appearance');
     // Bartik is uninstalled in the test profile and has the third "Install and
     // set as default" link.
-    $this->clickLink(t('Install and set as default'), 2);
+    $this->clickLink(t('Enable and set as default'), 2);
     // Test the confirmation message.
     $this->assertText('Bartik is now the default theme.');
     // Make sure Bartik is now set as the default theme in config.
@@ -410,9 +410,9 @@ public function testUninstallingThemes() {
   public function testInstallAndSetAsDefault() {
     $this->drupalGet('admin/appearance');
-    // Bartik is uninstalled in the test profile and has the third "Install and
+    // Bartik is uninstalled in the test profile and has the third "Enable and
     // set as default" link.
